package com.hw.dms.mapper;

import java.util.List;
import com.hw.dms.domain.DmsFlowCheckplanDetail;

/**
 * 设备盘点明细Mapper接口
 * 
 * @author xins
 * @date 2024-01-02
 */
public interface DmsFlowCheckplanDetailMapper 
{
    /**
     * 查询设备盘点明细
     * 
     * @param checkplanDetailId 设备盘点明细主键
     * @return 设备盘点明细
     */
    public DmsFlowCheckplanDetail selectDmsFlowCheckplanDetailByCheckplanDetailId(Long checkplanDetailId);

    /**
     * 查询设备盘点明细列表
     * 
     * @param dmsFlowCheckplanDetail 设备盘点明细
     * @return 设备盘点明细集合
     */
    public List<DmsFlowCheckplanDetail> selectDmsFlowCheckplanDetailList(DmsFlowCheckplanDetail dmsFlowCheckplanDetail);

    /**
     * 新增设备盘点明细
     * 
     * @param dmsFlowCheckplanDetail 设备盘点明细
     * @return 结果
     */
    public int insertDmsFlowCheckplanDetail(DmsFlowCheckplanDetail dmsFlowCheckplanDetail);

    /**
     * 修改设备盘点明细
     * 
     * @param dmsFlowCheckplanDetail 设备盘点明细
     * @return 结果
     */
    public int updateDmsFlowCheckplanDetail(DmsFlowCheckplanDetail dmsFlowCheckplanDetail);

    /**
     * 删除设备盘点明细
     * 
     * @param checkplanDetailId 设备盘点明细主键
     * @return 结果
     */
    public int deleteDmsFlowCheckplanDetailByCheckplanDetailId(Long checkplanDetailId);

    /**
     * 批量删除设备盘点明细
     * 
     * @param checkplanDetailIds 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteDmsFlowCheckplanDetailByCheckplanDetailIds(Long[] checkplanDetailIds);
}
